@@ -28,11 +28,6 @@ namespace log4cpp {
         flush();
     }
 
-    CategoryStream& CategoryStream::operator<<(CategoryStream::Separator separator) {
-        flush();
-        return *this;
-    }
-
     void CategoryStream::flush() {
         if (_buffer) {
             getCategory().log(getPriority(), _buffer->str());
@@ -40,4 +35,29 @@ namespace log4cpp {
             _buffer = NULL;
         }
     }
+     std::streamsize CategoryStream::width(std::streamsize wide ) {
+        if (getPriority() != Priority::NOTSET) {
+            if (!_buffer) {
+                if (!(_buffer = new std::ostringstream)) {
+                    // XXX help help help
+                }
+            }
+        }
+        return _buffer->width(wide); 
+    }
+    CategoryStream& CategoryStream::operator<< (cspf pf) {
+		return (*pf)(*this);
+    }
+    CategoryStream& eol (CategoryStream& os) {
+        if  (os._buffer) {
+		os.flush();
+        }
+        return os;
+    }
+    CategoryStream& left (CategoryStream& os) {
+        if  (os._buffer) {
+            os._buffer->setf(std::ios::left);
+        }
+        return os;
+    }
 }
