@@ -22,13 +22,10 @@
 
 namespace log4cpp {
 
-    HierarchyMaintainer* HierarchyMaintainer::_defaultMaintainer = NULL;
-
     HierarchyMaintainer& HierarchyMaintainer::getDefaultMaintainer() {
-        if (!_defaultMaintainer)
-            _defaultMaintainer = new HierarchyMaintainer();
+        static HierarchyMaintainer defaultMaintainer;
 
-        return *_defaultMaintainer;
+        return defaultMaintainer;
     }
 
     HierarchyMaintainer::HierarchyMaintainer() {
@@ -68,7 +65,6 @@ namespace log4cpp {
         if (NULL == result) {            
             if (name == "") {
                 result = new Category(name, NULL, Priority::INFO);
-                result->addAppender(new FileAppender("_", ::dup(fileno(stderr))));
             } else {
                 std::string parentName;
                 size_t dotIndex = name.find_last_of('.');
@@ -105,6 +101,21 @@ namespace log4cpp {
                 ((*i).second)->removeAllAppenders();
             }
         }
+        
+        try
+        {
+           for(handlers_t::const_iterator i = handlers_.begin(), last = handlers_.end(); i != last; ++i)
+              (**i)();
+        }
+        catch(...)
+        {
+        }
+        
+    }
+
+    void HierarchyMaintainer::register_shutdown_handler(shutdown_fun_ptr handler)
+    {
+        handlers_.push_back(handler); 
     }
 
     void HierarchyMaintainer::deleteAllCategories() {
