@@ -12,6 +12,8 @@
 #include <log4cpp/Priority.hh>
 #include <log4cpp/NDC.hh>
 #include <log4cpp/TimeStamp.hh>
+#include <log4cpp/FactoryParams.hh>
+#include <memory>
 
 #ifdef LOG4CPP_HAVE_SSTREAM
 #include <sstream>
@@ -22,6 +24,7 @@
 #include <iomanip>
 #include <ctime>
 #include <cmath>
+#include "Localtime.hh"
 
 #ifdef LOG4CPP_HAVE_INT64_T
 #ifdef LOG4CPP_HAVE_STDINT_H
@@ -119,7 +122,7 @@ namespace log4cpp {
 
     struct ProcessorTimeComponent : public PatternLayout::PatternComponent {
         virtual void append(std::ostringstream& out, const LoggingEvent& event) {
-            out << ::clock();
+            out << std::clock();
         }
     };
 
@@ -148,9 +151,9 @@ namespace log4cpp {
         }
 
         virtual void append(std::ostringstream& out, const LoggingEvent& event) {
-            struct tm *currentTime;
-            time_t t = event.timeStamp.getSeconds();
-            currentTime = std::localtime(&t);
+            struct std::tm currentTime;
+            std::time_t t = event.timeStamp.getSeconds();
+            localtime(&t, &currentTime);
             char formatted[100];
             std::string timeFormat;
             if (_printMillis) {
@@ -163,7 +166,7 @@ namespace log4cpp {
             } else {
                 timeFormat = _timeFormat1;
             }
-            std::strftime(formatted, sizeof(formatted), timeFormat.c_str(), currentTime);
+            std::strftime(formatted, sizeof(formatted), timeFormat.c_str(), &currentTime);
             out << formatted;
         }
 
@@ -208,11 +211,11 @@ namespace log4cpp {
 
     struct FormatModifierComponent : public PatternLayout::PatternComponent {
         FormatModifierComponent(PatternLayout::PatternComponent* component,
-                                int minWidth, int maxWidth) :
+                                size_t minWidth, size_t maxWidth, bool alignLeft) :
             _component(component) , 
-            _minWidth(std::abs(minWidth)),
+            _minWidth(minWidth),
             _maxWidth(maxWidth),
-            _alignLeft(minWidth < 0) {
+            _alignLeft(alignLeft) {
         }
 
         virtual ~FormatModifierComponent() {
@@ -223,11 +226,11 @@ namespace log4cpp {
             std::ostringstream s;
             _component->append(s, event);
             std::string msg = s.str();
-            if (_maxWidth > 0) {
+            if (_maxWidth > 0 && _maxWidth < msg.length()) {
                 msg.erase(_maxWidth);
             }
-            int fillCount = _minWidth - msg.length();
-            if (fillCount > 0) {
+            size_t fillCount = _minWidth - msg.length();
+            if (_minWidth > msg.length()) {
                 if (_alignLeft) {
                     out << msg << std::string(fillCount, ' ');
                 } else {
@@ -240,8 +243,8 @@ namespace log4cpp {
 
         private:
         PatternLayout::PatternComponent* _component;
-        int _minWidth;
-        int _maxWidth;
+        size_t _minWidth;
+        size_t _maxWidth;
         bool _alignLeft;
     };
 
@@ -253,7 +256,7 @@ namespace log4cpp {
     PatternLayout::PatternLayout() {
         try {
             setConversionPattern(DEFAULT_CONVERSION_PATTERN);
-        } catch(ConfigureFailure& e) {
+        } catch(ConfigureFailure&) {
         }
     }
 
@@ -281,7 +284,7 @@ namespace log4cpp {
         char ch;
         PatternLayout::PatternComponent* component = NULL;
         int minWidth = 0;
-        int maxWidth = 0;
+        size_t maxWidth = 0;
         clearConversionPattern();
         while (conversionStream.get(ch)) {
             if (ch == '%') {
@@ -347,6 +350,9 @@ namespace log4cpp {
                 case 'R':
                     component = new SecondsSinceEpochComponent();
                     break;
+                case 't':
+                    component = new ThreadNameComponent();
+                    break;
                 case 'u':
                     component = new ProcessorTimeComponent();
                     break;
@@ -364,7 +370,7 @@ namespace log4cpp {
                         literal = "";
                     }
                     if ((minWidth != 0) || (maxWidth != 0)) {
-                        component = new FormatModifierComponent(component, minWidth, maxWidth);
+                        component = new FormatModifierComponent(component, std::abs(minWidth), maxWidth, minWidth < 0);
                         minWidth = maxWidth = 0;
                     }
                     _components.push_back(component);
@@ -395,4 +401,35 @@ namespace log4cpp {
 
         return message.str();
     }
+
+    std::auto_ptr<Layout> create_pattern_layout(const FactoryParams& params)
+    {
+       std::string pattern;
+       params.get_for("pattern layout").optional("pattern", pattern);
+       std::auto_ptr<Layout> result(new PatternLayout);
+       PatternLayout* l = static_cast<PatternLayout*>(result.get());
+       if (pattern.empty() || pattern == "default")
+          return result;
+
+       if (pattern == "simple")
+       {
+          l->setConversionPattern(PatternLayout::SIMPLE_CONVERSION_PATTERN);
+          return result;
+       }
+
+       if (pattern == "basic")
+       {
+          l->setConversionPattern(PatternLayout::BASIC_CONVERSION_PATTERN);
+          return result;
+       }
+
+       if (pattern == "ttcc")
+       {
+          l->setConversionPattern(PatternLayout::TTCC_CONVERSION_PATTERN);
+          return result;
+       }
+       
+       l->setConversionPattern(pattern);
+       return result;
+   }
 }
