@@ -15,10 +15,21 @@ namespace log4cpp {
 
     namespace {
         const std::string names[10] = {
-            "FATAL", "ALERT", "CRIT", "ERROR", "WARN",
-            "NOTICE", "INFO", "DEBUG", "NOTSET", "UNKNOWN" 
+            "FATAL",
+			"ALERT",
+			"CRIT",
+			"ERROR",
+			"WARN",
+            "NOTICE",
+			"INFO",
+			"DEBUG",
+			"NOTSET",
+			"UNKNOWN" 
         };
-    }
+    }    
+
+    const int log4cpp::Priority::MESSAGE_SIZE = 8;
+    
 
     const std::string& Priority::getPriorityName(int priority) throw() {
          
@@ -40,13 +51,15 @@ namespace log4cpp {
 
 	if (value == -1) {
 	    if (priorityName == "EMERG") {
-		value = 0;
+		    value = 0;
 	    } else {
-		char* endPointer;
-		value = std::strtoul(priorityName.c_str(), &endPointer, 10);
-		if (*endPointer != 0) {
-		    throw std::invalid_argument(std::string("unknown priority name: '") + priorityName + "'");
-		}
+		    char* endPointer;
+		    value = std::strtoul(priorityName.c_str(), &endPointer, 10);
+		    if (*endPointer != 0) {
+		        throw std::invalid_argument(
+					std::string("unknown priority name: '") + priorityName + "'"
+				);
+		    }
 	    }
 	}
 	
