@@ -25,6 +25,7 @@
 #include <log4cpp/OstreamAppender.hh>
 #include <log4cpp/FileAppender.hh>
 #include <log4cpp/RollingFileAppender.hh>
+#include <log4cpp/AbortAppender.hh>
 #ifdef WIN32
 #include <log4cpp/Win32DebugAppender.hh>
 #include <log4cpp/NTEventLogAppender.hh>
@@ -33,6 +34,9 @@
 #ifdef LOG4CPP_HAVE_LIBIDSA
 #include <log4cpp/IdsaAppender.hh>
 #endif	// LOG4CPP_HAVE_LIBIDSA
+#ifdef LOG4CPP_HAVE_SYSLOG
+#include <log4cpp/SyslogAppender.hh>
+#endif
 
 // layouts
 #include <log4cpp/Layout.hh>
@@ -218,6 +222,16 @@ namespace log4cpp {
             appender = new RemoteSyslogAppender(appenderName, syslogName, 
                                                 syslogHost, facility, portNumber);
         }
+#ifdef LOG4CPP_HAVE_SYSLOG
+        else if (appenderType == "LocalSyslogAppender") {
+            std::string syslogName = _properties.getString(appenderPrefix + ".syslogName", "syslog");
+            int facility = _properties.getInt(appenderPrefix + ".facility", -1) * 8; // * 8 to get LOG_KERN, etc. compatible values. 
+            appender = new SyslogAppender(appenderName, syslogName, facility);
+        }
+#endif // LOG4CPP_HAVE_SYSLOG
+        else if (appenderType == "AbortAppender") {
+            appender = new AbortAppender(appenderName);
+        }
 #ifdef LOG4CPP_HAVE_LIBIDSA
         else if (appenderType == "IdsaAppender") {
             // default idsa name ???
@@ -320,7 +334,7 @@ namespace log4cpp {
         // then look for "category."
         std::string prefix("category");
         Properties::const_iterator from = _properties.lower_bound(prefix + '.');
-        Properties::const_iterator to = _properties.lower_bound(prefix + '/'); // '/' = '.' + 1
+        Properties::const_iterator to = _properties.lower_bound(prefix + (char)('.' + 1)); 
         for (Properties::const_iterator iter = from; iter != to; iter++) {
             categories.push_back((*iter).first.substr(prefix.size() + 1));
         }
