@@ -17,6 +17,10 @@
 #include <fcntl.h>
 #include <log4cpp/RollingFileAppender.hh>
 #include <log4cpp/Category.hh>
+#include <log4cpp/FactoryParams.hh>
+#include <memory>
+#include <stdio.h>
+
 #ifdef LOG4CPP_HAVE_SSTREAM
 #include <sstream>
 #endif
@@ -56,10 +60,16 @@ namespace log4cpp {
             std::ostringstream oldName;
             oldName << _fileName << "." << _maxBackupIndex << std::ends;
             ::remove(oldName.str().c_str());
-            size_t n = _fileName.length() + 1;
+                        size_t n = _fileName.length() + 1;
             for(unsigned int i = _maxBackupIndex; i > 1; i--) {
-            	std::string newName = oldName.str();
-                oldName.seekp(n, std::ios::beg);
+                std::string newName = oldName.str();
+#ifndef LOG4CPP_STLPORT_AND_BOOST_BUILD
+                                oldName.seekp(static_cast<std::ios::off_type>(n), std::ios::beg);
+#else
+                                // the direction parameter is broken in STLport 4.5.3, 
+                                // so we don't specify it (the code works without it)
+                                oldName.seekp(n);
+#endif
                 oldName << i-1 << std::ends;
                 ::rename(oldName.str().c_str(), newName.c_str());
             }
@@ -79,4 +89,17 @@ namespace log4cpp {
             }
         }
     }
+    
+   std::auto_ptr<Appender> create_roll_file_appender(const FactoryParams& params)
+   {
+      std::string name, filename;
+      bool append = true;
+      mode_t mode = 664;
+      int max_file_size = 0, max_backup_index = 0;
+      params.get_for("rool file appender").required("name", name)("filename", filename)("max_file_size", max_file_size)
+                                                     ("max_backup_index", max_backup_index)
+                                          .optional("append", append)("mode", mode);
+
+      return std::auto_ptr<Appender>(new RollingFileAppender(name, filename, max_file_size, max_backup_index, append, mode));
+   }
 }
