@@ -7,9 +7,9 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/TimeStamp.hh"
+#include <log4cpp/TimeStamp.hh>
 
-#include <string.h>
+#include <cstring>
 
 #ifdef LOG4CPP_HAVE_GETTIMEOFDAY
 #include <sys/time.h>
@@ -23,7 +23,7 @@
 
 namespace log4cpp {
 
-    TimeStamp TimeStamp::_startStamp;
+    LOG4CPP_EXPORT TimeStamp TimeStamp::_startStamp;
 
     TimeStamp::TimeStamp() {
 #ifdef LOG4CPP_HAVE_GETTIMEOFDAY
