@@ -1,7 +1,7 @@
 // testConfig.cpp : Derived from testPattern.cpp.
 //
 
-#include "log4cpp/Portability.hh"
+#include <log4cpp/Portability.hh>
 
 #ifdef WIN32
 #include <windows.h>
@@ -10,19 +10,19 @@
 #include <unistd.h>
 #endif
 
-#include <stdlib.h>
+#include <cstdlib>
 
-#include "log4cpp/Category.hh"
-#include "log4cpp/Appender.hh"
-#include "log4cpp/OstreamAppender.hh"
-#include "log4cpp/FileAppender.hh"
-#include "log4cpp/Layout.hh"
-#include "log4cpp/BasicLayout.hh"
-#include "log4cpp/Priority.hh"
-#include "log4cpp/NDC.hh"
-#include "log4cpp/PatternLayout.hh"
+#include <log4cpp/Category.hh>
+#include <log4cpp/Appender.hh>
+#include <log4cpp/OstreamAppender.hh>
+#include <log4cpp/FileAppender.hh>
+#include <log4cpp/Layout.hh>
+#include <log4cpp/BasicLayout.hh>
+#include <log4cpp/Priority.hh>
+#include <log4cpp/NDC.hh>
+#include <log4cpp/PatternLayout.hh>
 
-#include "log4cpp/SimpleConfigurator.hh"
+#include <log4cpp/SimpleConfigurator.hh>
 
 double calcPi()
 {
@@ -45,7 +45,7 @@ int main(int argc, char* argv[])
         /* looking for the init file in $srcdir is a requirement of
            automake's distcheck target.
         */
-        char* srcdir = ::getenv("srcdir");
+        char* srcdir = std::getenv("srcdir");
         std::string initFileName;
         if (srcdir == NULL) {
             initFileName = "./log4cpp.init";
@@ -93,8 +93,8 @@ int main(int argc, char* argv[])
     sub2.error("%s %s %d", "test", "vform", 123);
     sub2.warnStream() << "streamed warn";
 
-    sub2 << log4cpp::Priority::WARN << "warn2.." << "..warn3..value=" << 0 << 
-        log4cpp::CategoryStream::ENDLINE << "..warn4";
+    sub2 << log4cpp::Priority::WARN << "warn2.." << "..warn3..value=" << 0 
+         << log4cpp::eol << "..warn4";
 
     log4cpp::Category::shutdown();
 
